==> guile-2.0.9-i486-1.txz: usr/lib/guile/2.0/ccache/system/repl/error-handling.go <==
GOOF----LE-4-2.0t'      ]  4     h      ] g  guile	 	g  define-module*	 	 	g  system	g  repl	g  error-handling		 	
g  filenameS	f  system/repl/error-handling.scm	g  importsS	
g  base	g  pmatch	
 	 	g  vm	g  
trap-state	 	 	g  debug	 	 	g  ice-9	g  format	 	 	 	g  exportsS	g  call-with-error-handling	g  with-error-handling	  	!g  set-current-module	"! 	#! 	$g  call-with-output-string	%g  
vector-length	&g  print-exception	'g  error-string	(g  on-errorS	)(	*g  
post-errorS	+*		,g  	pass-keysS	-,		.g  trap-handlerS	/.		0)+-/ 	1g  catch	2g  quit	32 	4g  current-input-port	5g  current-output-port	6g  current-error-port	7g  %stacks	8g  narrow-stack->vector	9g  
make-stack	:f  Trap ~d: ~a	;g  
make-debug	<g  with-input-from-port	=g  with-output-to-port	>g  with-error-to-port	?f  ~a~%	@f  Entering a new prompt.  	Af  0Type `,bt' for a backtrace or `,q' to continue.
	B 	Cg  
start-repl	DBC 	EBC 	Fg  debugS	Gg  pass	Hg  disabled	Ig  error	Jf  Unknown trap-handler strategy	Kg  with-default-trap-handler	Lg  %start-stack	Mg  report	Ng  memq	Og  throw	Pg  run-hook	Qg  before-error-hook	Rg  after-error-hook	Sg  force-output	Tg  
procedure?	Uf  Unknown post-error strategy	Vg  	backtrace	Wg  print-frames	Xf  Unknown on-error strategy	Yg  make-syntax-transformer	ZY 	[Y 	\g  macro	]g  $sc-dispatch	^] 	_] 	`g  any	a`` 	bg  
syntax-object	cg  top	dc 	eg  ribcage	fg  dummy	gg  form	hfg 	ig  m-$dLejLYtGKAYf43NGFtRp5-9147	jic 	kjd 	lf  l-$dLejLYtGKAYf43NGFtRp5-9152	mf  l-$dLejLYtGKAYf43NGFtRp5-9153	nlm 	oehkn 	pe 	qg  x	rq 	sj 	tf  l-$dLejLYtGKAYf43NGFtRp5-9149	ut 	versu 	wdopv 	xg  hygiene	yx 	zbwy 	{g  lambda	|b{wy 	}g  syntax-violation	~} 	}  f  -source expression failed to match any patternC 5     hx  r   ]4	
 5 4# >  "  G   $%& h(      ]	
4L 5$  L 
"   LL6         g  port
		& g  frame		&  g  filenamef  system/repl/error-handling.scm
	&			'			'			'			'	3		'		&	(	 		&   C       h      ] O 6              g  stack
		 g  key		 g  args			  g  filenamef  system/repl/error-handling.scm
	$
		%	 			  g  nameg  error-string C'R013456789:;<=>?@AEF hP      ] L$  ?4L>  "  G  4>  "  G  4>  "  G  "   L 6        g  filenamef  system/repl/error-handling.scm
	L				M				O			O			O			P		#	P		(	P		1	Q		6	Q		;	Q		I	R		O	R	 		O
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C 	   hp     ]#[$  	["  44 5

$  "  5$  45"  4
5LLL O 6      g  frame
		p g  trap-idx		p g  	trap-name			p g  tag			p g  stack		2	p g  	error-msg		L	p g  debug		Y	p  g  filenamef  system/repl/error-handling.scm
	8			9		
	9			:			9			;			<		*	F		2	;		2	9		:	G		;	H		@	H	'	F	H		L	9		O	J		Y	9		p	1	 		p	  g  nameg  debug-trap-handler CG     h      ]C           g  frame
		 g  trap-idx		 g  	trap-name			  g  filenamef  system/repl/error-handling.scm
	T	 			  g  nameg  null-trap-handler CHIJ1KL       h   Y   ] L 6       Q       g  filenamef  system/repl/error-handling.scm
	a	
			a	 			
   C    h   Y   ] ML O 6 Q       g  filenamef  system/repl/error-handling.scm
	_			`	 		
   CMNO<=>PQ&RS  hH   q   ] 4>  "  G  4LLL >  "  G  4>  "  G  L6     i       g  filenamef  system/repl/error-handling.scm
	j			k			l		,	m		C	n	 		C
   C    h   Y   ] LLL LO 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    h@      - 1 3 4 L5$   @4L L LO >  "  G  C        g  key
			? g  args			?  g  filenamef  system/repl/error-handling.scm
	e			
	f			f			g			1	 			?
   CNO  h       - 1 3 4 L 5$   @C       g  key
			  g  args			   g  filenamef  system/repl/error-handling.scm
	q			
	r			r			s	 			 
   CTNO        h(      - 1 3 4 L5$  "  L  @           g  k
			$ g  args			$  g  filenamef  system/repl/error-handling.scm
	v	
	
	w			w		$	w	 			$
   CUN789';<=>?@AEF     hH      ] 4L>  "  G  4>  "  G  4>  "  G  L 6          g  filenamef  system/repl/error-handling.scm
 		 		 		 		 		 		" 		+ 		0 		5 		? 		E 	 
		E
   C        h   Y   ] LLL O 6       Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C 	   hx   J  - 1 3 4 L5$  C[$  	["  445	
$  "  54 54
5L LLO 6 B      g  key
			w g  args			w g  tag		*	w g  stack		H	w g  	error-msg		U	w g  debug		b	w  g  filenamef  system/repl/error-handling.scm
	|			
	}			}			~	 	 	~		$		 	*	~		- 		0 		@ 	 	H 		H	~		K 	!	U	~		X 		b	~		w	1	 			w
   CN<=>PQ&RS     hH   v   ] 4>  "  G  4LLL >  "  G  4>  "  G  L6     n       g  filenamef  system/repl/error-handling.scm
 		 		 		, 		C 	 		C
   C       h   Y   ] LLL LO 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    h@      - 1 3 4 L5$  C4L L LO >  "  G  C              g  key
			9 g  args			9  g  filenamef  system/repl/error-handling.scm
 			
 		 			1	 			9
   CVN789<=>WPQ&RS    hX      ] 4L>  "  G  4>  "  G  4L LL>  "  G  4>  "  G  L 6   w       g  filenamef  system/repl/error-handling.scm
 		 		 		' 		> 		U 	 		U
   C      h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    hp     - 1 3 4 L5$  C[$  	["  445	
$  "  54L L LO >  "  G  C          g  key
			m g  args			m g  tag		*	m g  frames		H	m  g  filenamef  system/repl/error-handling.scm
 			
 		 		 	 	  		$ 	 	* 		- 		0 		@ 	'	H 		H 		K	1	 			m
   C       h   w   - 1 3 C     o       g  key
			 g  args			  g  filenamef  system/repl/error-handling.scm
 		 			
   CNO h(      - 1 3 4 L5$  "  L  @           g  k
			$ g  args			$  g  filenamef  system/repl/error-handling.scm
 	
	
 		 		$ 	 			$
   CX   hx    - /   0   3 
#  #  #  #  45 45 45 HO 	Q 	$  	"  &	$  
"  $  "  	4
5K O $  O "  5$  O "  !45$  
O "  	45$  O "  d$  O "  J$  O "  0	$  "  !45$  
O "  	456      g  thunk
	x g  on-error	x g  
post-error		x g  	pass-keys		x g  trap-handler		x g  in		Jx g  out		Jx g  err		Jx g  le-trap-handler		Qx g  debug-trap-handler			]x  
g  filenamef  system/repl/error-handling.scm
	*
		+	-	%	+	A	/	,	.	9	,	E	<	-		A	.	
	F	/	
	J	-		o	X	 	\	 	\	 	\	 	c	 	u	
 	u		 	x	
 	x	 	x	
	z	V 	
` 		n 	
r 	v 	
x	^	 	x
g  on-errorSg  
post-errorS	g  	pass-keysS	g  trap-handlerS	   g  nameg  call-with-error-handling CR4[\_az|       h   ?   ]  C7       g  dummy
		 g  form		  			   C  h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  system/repl/error-handling.scm
 
 		"  g  
macro-typeg  syntax-rulesg  patternsg  form   C5RC       j       g  m
		,  g  filenamef  system/repl/error-handling.scm		
	$
	*
 	q
   C6 

==> guile-2.0.11-i486-2.txz: usr/lib/guile/2.0/ccache/system/repl/error-handling.go <==
GOOF----LE-4-2.0t'      ]  4     h      ] g  guile	 	g  define-module*	 	 	g  system	g  repl	g  error-handling		 	
g  filenameS	f  system/repl/error-handling.scm	g  importsS	
g  base	g  pmatch	
 	 	g  vm	g  
trap-state	 	 	g  debug	 	 	g  ice-9	g  format	 	 	 	g  exportsS	g  call-with-error-handling	g  with-error-handling	  	!g  set-current-module	"! 	#! 	$g  call-with-output-string	%g  
vector-length	&g  print-exception	'g  error-string	(g  on-errorS	)(	*g  
post-errorS	+*		,g  	pass-keysS	-,		.g  trap-handlerS	/.		0)+-/ 	1g  catch	2g  quit	32 	4g  current-input-port	5g  current-output-port	6g  current-error-port	7g  %stacks	8g  narrow-stack->vector	9g  
make-stack	:f  Trap ~d: ~a	;g  
make-debug	<g  with-input-from-port	=g  with-output-to-port	>g  with-error-to-port	?f  ~a~%	@f  Entering a new prompt.  	Af  0Type `,bt' for a backtrace or `,q' to continue.
	B 	Cg  
start-repl	DBC 	EBC 	Fg  debugS	Gg  pass	Hg  disabled	Ig  error	Jf  Unknown trap-handler strategy	Kg  with-default-trap-handler	Lg  %start-stack	Mg  report	Ng  memq	Og  throw	Pg  run-hook	Qg  before-error-hook	Rg  after-error-hook	Sg  force-output	Tg  
procedure?	Uf  Unknown post-error strategy	Vg  	backtrace	Wg  print-frames	Xf  Unknown on-error strategy	Yg  make-syntax-transformer	ZY 	[Y 	\g  macro	]g  $sc-dispatch	^] 	_] 	`g  any	a`` 	bg  
syntax-object	cg  top	dc 	eg  ribcage	fg  dummy	gg  form	hfg 	ig  m-rhquqkE0yKuN5k2jA2ajEM-9047	jic 	kjd 	lf  l-rhquqkE0yKuN5k2jA2ajEM-9052	mf  l-rhquqkE0yKuN5k2jA2ajEM-9053	nlm 	oehkn 	pe 	qg  x	rq 	sj 	tf  l-rhquqkE0yKuN5k2jA2ajEM-9049	ut 	versu 	wdopv 	xg  hygiene	yx 	zbwy 	{g  lambda	|b{wy 	}g  syntax-violation	~} 	}  f  -source expression failed to match any patternC 5     hx  r   ]4	
 5 4# >  "  G   $%& h(      ]	
4L 5$  L 
"   LL6         g  port
		& g  frame		&  g  filenamef  system/repl/error-handling.scm
	&			'			'			'			'	3		'		&	(	 		&   C       h      ] O 6              g  stack
		 g  key		 g  args			  g  filenamef  system/repl/error-handling.scm
	$
		%	 			  g  nameg  error-string C'R013456789:;<=>?@AEF hP      ] L$  ?4L>  "  G  4>  "  G  4>  "  G  "   L 6        g  filenamef  system/repl/error-handling.scm
	L				M				O			O			O			P		#	P		(	P		1	Q		6	Q		;	Q		I	R		O	R	 		O
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C 	   hp     ]#[$  	["  44 5

$  "  5$  45"  4
5LLL O 6      g  frame
		p g  trap-idx		p g  	trap-name			p g  tag			p g  stack		2	p g  	error-msg		L	p g  debug		Y	p  g  filenamef  system/repl/error-handling.scm
	8			9		
	9			:			9			;			<		*	F		2	;		2	9		:	G		;	H		@	H	'	F	H		L	9		O	J		Y	9		p	1	 		p	  g  nameg  debug-trap-handler CG     h      ]C           g  frame
		 g  trap-idx		 g  	trap-name			  g  filenamef  system/repl/error-handling.scm
	T	 			  g  nameg  null-trap-handler CHIJ1KL       h   Y   ] L 6       Q       g  filenamef  system/repl/error-handling.scm
	a	
			a	 			
   C    h   Y   ] ML O 6 Q       g  filenamef  system/repl/error-handling.scm
	_			`	 		
   CMNO<=>PQ&RS  hH   q   ] 4>  "  G  4LLL >  "  G  4>  "  G  L6     i       g  filenamef  system/repl/error-handling.scm
	j			k			l		,	m		C	n	 		C
   C    h   Y   ] LLL LO 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    h@      - 1 3 4 L5$   @4L L LO >  "  G  C        g  key
			? g  args			?  g  filenamef  system/repl/error-handling.scm
	e			
	f			f			g			1	 			?
   CNO  h       - 1 3 4 L 5$   @C       g  key
			  g  args			   g  filenamef  system/repl/error-handling.scm
	q			
	r			r			s	 			 
   CTNO        h(      - 1 3 4 L5$  "  L  @           g  k
			$ g  args			$  g  filenamef  system/repl/error-handling.scm
	v	
	
	w			w		$	w	 			$
   CUN789';<=>?@AEF     hH      ] 4L>  "  G  4>  "  G  4>  "  G  L 6          g  filenamef  system/repl/error-handling.scm
 		 		 		 		 		 		" 		+ 		0 		5 		? 		E 	 
		E
   C        h   Y   ] LLL O 6       Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C 	   hx   J  - 1 3 4 L5$  C[$  	["  445	
$  "  54 54
5L LLO 6 B      g  key
			w g  args			w g  tag		*	w g  stack		H	w g  	error-msg		U	w g  debug		b	w  g  filenamef  system/repl/error-handling.scm
	|			
	}			}			~	 	 	~		$		 	*	~		- 		0 		@ 	 	H 		H	~		K 	!	U	~		X 		b	~		w	1	 			w
   CN<=>PQ&RS     hH   v   ] 4>  "  G  4LLL >  "  G  4>  "  G  L6     n       g  filenamef  system/repl/error-handling.scm
 		 		 		, 		C 	 		C
   C       h   Y   ] LLL LO 6     Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLL O 6     Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    h@      - 1 3 4 L5$  C4L L LO >  "  G  C              g  key
			9 g  args			9  g  filenamef  system/repl/error-handling.scm
 			
 		 			1	 			9
   CVN789<=>WPQ&RS    hX      ] 4L>  "  G  4>  "  G  4L LL>  "  G  4>  "  G  L 6   w       g  filenamef  system/repl/error-handling.scm
 		 		 		' 		> 		U 	 		U
   C      h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	4			5	 		
   C    h   Y   ] LLLLL O 6   Q       g  filenamef  system/repl/error-handling.scm
	2			3	
 		
   C    hp     - 1 3 4 L5$  C[$  	["  445	
$  "  54L L LO >  "  G  C          g  key
			m g  args			m g  tag		*	m g  frames		H	m  g  filenamef  system/repl/error-handling.scm
 			
 		 		 	 	  		$ 	 	* 		- 		0 		@ 	'	H 		H 		K	1	 			m
   C       h   w   - 1 3 C     o       g  key
			 g  args			  g  filenamef  system/repl/error-handling.scm
 		 			
   CNO h(      - 1 3 4 L5$  "  L  @           g  k
			$ g  args			$  g  filenamef  system/repl/error-handling.scm
 	
	
 		 		$ 	 			$
   CX   hx    - /   0   3 
#  #  #  #  45 45 45 HO 	Q 	$  	"  &	$  
"  $  "  	4
5K O $  O "  5$  O "  !45$  
O "  	45$  O "  d$  O "  J$  O "  0	$  "  !45$  
O "  	456      g  thunk
	x g  on-error	x g  
post-error		x g  	pass-keys		x g  trap-handler		x g  in		Jx g  out		Jx g  err		Jx g  le-trap-handler		Qx g  debug-trap-handler			]x  
g  filenamef  system/repl/error-handling.scm
	*
		+	-	%	+	A	/	,	.	9	,	E	<	-		A	.	
	F	/	
	J	-		o	X	 	\	 	\	 	\	 	c	 	u	
 	u		 	x	
 	x	 	x	
	z	V 	
` 		n 	
r 	v 	
x	^	 	x
g  on-errorSg  
post-errorS	g  	pass-keysS	g  trap-handlerS	   g  nameg  call-with-error-handling CR4[\_az|       h   ?   ]  C7       g  dummy
		 g  form		  			   C  h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  system/repl/error-handling.scm
 
 		"  g  
macro-typeg  syntax-rulesg  patternsg  form   C5RC       j       g  m
		,  g  filenamef  system/repl/error-handling.scm		
	$
	*
 	q
   C6 
